@@ -4,7 +4,11 @@ options(
     setup=Bunch(
         name="metamake",
         packages=['metamake'],
+        version="1.0.1",
         license="BSD",
+        author="Matt Pizzimenti",
+        author_email="mjpizz+metamake@gmail.com",
+        url="http://pypi.python.org/pypi/metamake/",
         description="Metamake is a dead-simple task-based automation tool written in Python.",
         long_description='''\
 Description
@@ -38,42 +42,80 @@ Advanced Features
 
 Backwards-compatibility with Make
 ---------------------------------
-You will notice that whenever you run Metamake, a "Makefile" will be
+To make things easier on newcomers to Metamake, a "Makefile" can be
 created in your working directory that contains a bootstrapped version of
 Metamake inside.  This allows anybody to build your project without needing
-Metamake to be installed. With the bootstrapped Makefile, you can type
+Metamake to be installed.  With the bootstrapped Makefile, you can type
 ``make <args>`` to achieve the same effect as ``metamake <args>``.  Whenever you
 update Metamake on your system, these bootstrapped Makefiles will be updated
-automatically next time you execute Metamake for that project.  Commit these
-Makefiles to your repository so that other people can check out your project
-and build it without installing Metamake.
+automatically next time you execute Metamake for that project.  You should 
+commit these Makefiles to your repository so that other people can check out
+your project and build it without installing Metamake.  To create a Makefile
+bootstrap::
 
+    from metamake import task, shell, bootstrap
+    
+    bootstrap("Makefile")
+    
+    # ...
+
+What if you already have a Makefile that you are using for other purposes?
+That's easy to solve, simply by specifying a different filename::
+    
+    from metamake import task, shell, bootstrap
+    
+    bootstrap("Makefile.meta")
+    
+    # ...
+    
 Easy Commandline Flag Definition
 --------------------------------
 Finally, Metamake allows you to define commandline flags that can be passed
 into your application.  These flags will work regardless of whether you use
 the 'metamake' tool or the bootstrapped Makefile::
 
-    from metamake import task, shell, path, Flag
+    from metamake import task, Flag
 
     Flag("cleanfirst").explain("set this flag to 'true' to do a clean build")
-
-    @task
-    def build()
-        """builds the widget"""
-        if Flag("cleanfirst").value is "true":
-            clean()
-        shell("qmake")
-
-    @task
-    def clean()
-        """cleans the widget"""
-        shell("rm -rf build")
+    
+    # determine if the flag was given on the commandline
+    if Flag("cleanfirst").given:
+        print "got flag"
+    
+    # determine the value of the flag
+    if Flag("cleanfirst").value == "true":
+        print "flag was True"
 
 When you execute ``metamake ls`` on the commandline, you will see these flags
 listed underneath all of the task definitions, with the explanation that
 you provided as documentation.
 
+From the first example, asking if the value is "true" or "false" is a bit unweildy
+for a boolean value.  This gets even worse for flags that take a restricted set of
+values, for example a range of integers.  The ``explain`` method can take a few
+more parameters to help you out here::
+
+    from metamake import task, Flag
+
+    Flag("debuglevel").explain("this flag sets the debug level for the build", convert=int, allow=[1,2,3,4])
+    
+    # determine the value of the flag, which will
+    # automatically be converted to an integer
+    if Flag("debuglevel").value == 3:
+        print "flag was the integer 3"
+
+You can also grab the Flag instance instead of always referring to it by it's
+string name::
+
+    from metamake import task, Flag
+    
+    cleanflag = Flag("cleanfirst")
+    debugflag = Flag("debuglevel")
+    
+    if cleanflag.given and debugflag.value == 3:
+        print "we just checked the flag instances"
+    
+
 Readable, Cross-platform Filesystem Manipulation
 ------------------------------------------------
 Jason Orendorff's excellent `path.py <http://pypi.python.org/pypi/path.py/>`_
@@ -116,14 +158,7 @@ methods:  ``update``, ``build``, and ``clean``::
         gadgetlib.update()
         gadgetlib.build()
         shell("qmake")
-
-*NOTE:* in this example, build_cmd and clean_cmd are optional
-
 ''',
-        version="1.0.0",
-        author="Matt Pizzimenti",
-        author_email="mjpizz+metamake@gmail.com",
-        url="http://pypi.python.org/pypi/metamake/",
         entry_points='''
 [console_scripts]
 mm = metamake:metamake_bin
